/* jshint undef: true, unused: true */
/* global module, require, Packages */
/* global videoDeviceThumbnailHandler */

var facade = require("facade");
var Objects = require("convenience").Objects;
var _ = require("lodash");

var Permissions = Packages.cattura.web.server.properties.Permissions;

var deviceProxy = facade.retrieveProxy("DeviceProxy");


var api = {
    title: "Devices",
    description: "Provides information about, and methods to work with, audio and video devices.",
    version: 1,
    methods: {
        getAudioDevices: {
            name: "getAudioDevices",
            description: "Returns a listing of known audio devices.",
            verb: "get",
            endpoint: "devices/audio",
            callback: function() {
                return deviceProxy.getAudioDevices();
            }
        },
        getAudioDevice: {
            name: "getAudioDevice",
            description: "Returns a single specified audio device.",
            verb: "get",
            endpoint: "devices/audio/{id}",
            params: {
                id: {type: "string", description: "the ID of the device to get"}
            },
            callback: function(id) {
                return deviceProxy.getDevice(id);
            }
        },
        getVideoDevices: {
            name: "getVideoDevices",
            description: "Returns a listing of known video devices.",
            verb: "get",
            endpoint: "devices/video",
            callback: function() {
                return _(Objects.toJS(deviceProxy.getVideoDevices())).mapValues(function (device) {
                    return {
                        thumbnail: "api/1/devices/video/" + device.sanitizedID + "/thumbnail",
                        height: device.height,
                        configStructure: device.configStructure,
                        width: device.width,
                        pluginID: device.pluginID,
                        driver: device.driver,
                        fps: device.FPS,
                        usbbusInfo: device.USBBusInfo,
                        usbdevice: device.USBDevice,
                        type: device.type,
                        sanitizedID: device.sanitizedID,
                        prettyName: device.prettyName,
                        description: device.description,
                        tested: device.tested,
                        usable: device.usable,
                        name: device.name
                    };
                }).value();
            }
        },
        getVideoDevice: {
            name: "getVideoDevice",
            description: "Returns a single specified video device.",
            verb: "get",
            endpoint: "devices/video/{id}",
            params: {
                id: {type: "string", description: "the ID of the device to get"}
            },
            callback: function(id) {
                var device = deviceProxy.getDevice(id);
                return {
                    thumbnail: "api/1/devices/video/" + device.sanitizedID + "/thumbnail",
                    height: device.height,
                    configStructure: device.configStructure,
                    width: device.width,
                    pluginID: device.pluginID,
                    driver: device.driver,
                    fps: device.FPS,
                    usbbusInfo: device.USBBusInfo,
                    usbdevice: device.USBDevice,
                    type: device.type,
                    sanitizedID: device.sanitizedID,
                    prettyName: device.prettyName,
                    description: device.description,
                    tested: device.tested,
                    usable: device.usable,
                    name: device.name
                };
            }
        },
        getVideoDeviceThumbnail: {
            name: "getVideoDeviceThumbnail",
            description: "Returns the thumbnail for single specified video device.",
            verb: "get",
            endpoint: "devices/video/{id}/thumbnail",
            params: {
                id: {type: "string", description: "the ID of the device to get"}
            },
            handler: videoDeviceThumbnailHandler
        },
        redetect: {
            name: "redetect",
            description: "Redetect all devices on the recorder.",
            verb: "post",
            endpoint: "devices/redetect",
            require: Permissions.MANAGE_DEVICES,
            callback: function() {
                deviceProxy.redetect();
                return true;
            }
        },
        redetectProgress: {
            name: "redetectProgress",
            description: "Redetect all devices on the recorder.",
            verb: "get",
            endpoint: "devices/redetect/progress",
            callback: function() {
                return deviceProxy.getDetectionProgress();
            }
        }
    }
};

module.exports = api;
