/* jshint undef: true, unused: true */
/* global module, require, Packages */

var facade = require("facade");

var Permissions = Packages.cattura.web.server.properties.Permissions;

var RESTART_DELAY_MILLIS = 1000;
var setTimeout = setTimeout || require("timeout").setTimeout;

var api = {
    title: "Maintenance",
    description: "Maintenance tasks, such as rebooting.",
    version: 1,
    methods: {
        reboot: {
            name: "reboot",
            description: "Perform a reboot of this recorder.",
            verb: "post",
            require: Permissions.MANAGE_SETTINGS,
            endpoint: "maintenance/reboot",
            callback: function() {
                setTimeout(function () {
                    facade.sendNotification(facade.REBOOT);
                }, RESTART_DELAY_MILLIS);

                return true;
            }
        },
        poweroff: {
            name: "poweroff",
            description: "Power off the recorder.",
            verb: "post",
            require: Permissions.MANAGE_SETTINGS,
            endpoint: "maintenance/poweroff",
            callback: function() {
                setTimeout(function () {
                    facade.sendNotification(facade.POWER_OFF);
                }, RESTART_DELAY_MILLIS);

                return true;
            }
        },
        restart: {
            name: "restart",
            description: "Perform a restart of CaptureCast Pro.",
            verb: "post",
            require: Permissions.MANAGE_SETTINGS,
            endpoint: "maintenance/restart",
            callback: function() {
                setTimeout(function () {
                    facade.sendNotification(facade.RESTART);
                }, RESTART_DELAY_MILLIS);

                return true;
            }
        },
        shutdown: {
            name: "shutdown",
            description: "Shut down CaptureCast Pro.",
            verb: "post",
            require: Permissions.MANAGE_SETTINGS,
            endpoint: "maintenance/shutdown",
            callback: function() {
                setTimeout(function () {
                    facade.sendNotification(facade.DIE);
                }, RESTART_DELAY_MILLIS);

                return true;
            }
        },
        restartMediaProcessingModule: {
            name: "restartMediaProcessingModule",
            description: "Restarts only the media processing components",
            verb: "post",
            require: Permissions.MANAGE_SETTINGS,
            endpoint: "maintenance/restartMediaProcessingModule",
            callback: function() {
                facade.sendNotification(facade.RESTART_MEDIA_PROCESSING_MODULE);
                return true;
            }
        },
        runMaintenance: {
            name: "runMaintenance",
            description: "Runs maintenance on the operation system. May result in a reboot.",
            verb: "post",
            require: Permissions.MANAGE_SETTINGS,
            endpoint: "maintenance/runMaintenance",
            callback: function() {
                facade.sendNotification(facade.RUN_MAINTENANCE);
                return true;
            }
        }
    }
};

module.exports = api;
