/* jshint undef: true, unused: true */
/* global module, Packages, require */

var facade = require("facade");
var Objects = require("convenience").Objects;

var Permissions = Packages.cattura.web.server.properties.Permissions;

var SETTINGS = facade.retrieveProxy("SettingsProxy");

var api = {
    title: "Settings",
    description: "Provides a programmatic way to manage the settings on the recorder.",
    version: 1,
    methods: {
        getSetting: {
            name: "getSetting",
            description: "Returns a single user setting for this recorder.",
            verb: "get",
            require: Permissions.VIEW,
            endpoint: "settings/{setting}",
            params: {
                setting: {type: "string", description: "the name of the setting"},
            },
            callback: function (setting) {
                var settings = Objects.toJS(SETTINGS.getUserSettings().toMap(), true);
                if (!(setting in settings))
                {
                    return null;
                }

                return settings[setting];
            }
        },
        setSetting: {
            name: "setSetting",
            description: "Update a single user setting on this recorder. Returns the updated value of the setting.",
            verb: "post",
            require: Permissions.MANAGE_SETTINGS,
            endpoint: "settings/{setting}",
            params: {
                setting: {type: "string", description: "the name of the setting"},
                value: {description: "the value to set the setting to"}
            },
            callback: function(setting, value) {
                SETTINGS.set(setting, value);
                return value;
            }
        },
        getAll: {
            name: "getSettings",
            description: "Returns all user settings for the recorder.",
            verb: "get",
            require: Permissions.VIEW,
            endpoint: "settings",
            callback: function() {
                return SETTINGS.getUserSettings().toMap();
            }
        },
        setAll: {
            name: "setSettings",
            description: "Update multiple user settings on the recorder. Returns an updated set of all of the settings on the recorder. Will not erase other settings",
            verb: "post",
            require: Permissions.MANAGE_SETTINGS,
            endpoint: "settings",
            params: {
                settings: {type: "json", description: "JSON object containing settings"},
            },
            callback: function (settings) {
                SETTINGS.set(JSON.parse(settings));
                return SETTINGS.getUserSettings().toMap();
            }
        }
    }
};

module.exports = api;
