/* jshint undef: true, unused: true */
/* global module, require, Packages */

var facade = require("facade");

var ApplicationFacade = Packages.cattura.agents.configuration.controller.facade.ApplicationFacade;
var Permissions = Packages.cattura.web.server.properties.Permissions;
var DataKeys = Packages.cattura.web.server.properties.DataKeys;
var Role = Packages.cattura.web.server.interfaces.User.Role;

var userProxy = facade.retrieveProxy("UserProxy");


var api = {
    title: "Users",
    description: "Provides access to and methods to manage the local users in CaptureCast.",
    version: 1,
    methods: {
        getAll: {
            name: "getUsers",
            description: "List out all local users in CaptureCast.",
            verb: "get",
            require: Permissions.MANAGE_USERS,
            endpoint: "users",
            callback: function () {
                return userProxy.getUsers();
            }
        },
        getMyUser: {
            name: "getMyUser",
            description: "Get the user associated with the request.",
            verb: "get",
            endpoint: "users/me",
            callback: function (request) {
                return request.data(DataKeys.USER);
            }
        },
        getUser: {
            name: "getUser",
            description: "Get the information for a single local user in CaptureCast.",
            verb: "get",
            require: Permissions.MANAGE_USERS,
            endpoint: "users/{id}",
            params: {
                id: {type: "integer", description: "User id"},
            },
            callback: function (id) {
                return userProxy.getUser(id);
            }
        },
        create: {
            name: "createUser",
            description: "Create a new local user in CaptureCast.",
            verb: "post",
            require: Permissions.MANAGE_USERS,
            endpoint: "users",
            params: {
                username: {type: "string", description: "name of user, must be unique to that specific user"},
                password: {type: "string", description: "password of user"},
                roles: {type: "list of strings", description: "comma-separated list of roles to grant the user"},
                emailAddress: {type: "string", description: "email address of user"}
            },
            notification: ApplicationFacade.CREATE_USER
        },
        update: {
            name: "updateUser",
            description: "Update a new local user in CaptureCast.",
            verb: "post",
            require: Permissions.MANAGE_USERS,
            endpoint: "users/{id}",
            params: {
                id: {type: "integer", description: "User id"},
                username: {type: "string", description: "name of user, must be unique to that specific user"},
                password: {type: "string", description: "password of user"},
                roles: {type: "list of strings", description: "comma-separated list of roles to grant the user"},
                emailAddress: {type: "string", description: "email address of user"}
            },
            notification: ApplicationFacade.UPDATE_USER
        },
        delete: {
            name: "deleteUser",
            description: "Delete a new local user in CaptureCast.",
            verb: "delete",
            require: Permissions.MANAGE_USERS,
            endpoint: "users/{id}",
            params: {
                id: {type: "integer", description: "User id"}
            },
            notification: ApplicationFacade.DELETE_USER
        },
        getRoles: {
            name: "getRoles",
            description: "Get all available roles in CaptureCast.",
            verb: "get",
            require: Permissions.MANAGE_USERS,
            endpoint: "roles",
            callback: function () {
                return Role.asMap();
            }
        }
    }
};

module.exports = api;
